Crate gpui_util

Crate gpui_util 

Modules

arc_cow

Macros

debug_panic
maybe
Expands to an immediately-invoked function expression. Good for using the ? operator in functions which do not return an Option or Result.

Structs

Deferred
LogErrorFuture
LogErrorWithBacktraceFuture
UnwrapFuture

Traits

ResultExt
TryFutureExt
TryFutureExtBacktrace
{:?}-formatting companion to TryFutureExt; emits a backtrace for anyhow::Error. Prefer TryFutureExt unless a backtrace is genuinely wanted.

Functions

defer
Run the given function when the returned value is dropped (unless it’s cancelled).
log_err
measure
post_inc
some_or_debug_panic