Modules
Macros
- debug_
panic - maybe
- Expands to an immediately-invoked function expression. Good for using the ? operator in functions which do not return an Option or Result.
Structs
Traits
- Result
Ext - TryFuture
Ext - TryFuture
ExtBacktrace {:?}-formatting companion toTryFutureExt; emits a backtrace foranyhow::Error. PreferTryFutureExtunless a backtrace is genuinely wanted.
Functions
- defer
- Run the given function when the returned value is dropped (unless it’s cancelled).
- log_err
- measure
- post_
inc - some_
or_ debug_ panic